==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/RegistryRegionArmDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Details for each region the registry is in
 * @property acrDetails List of ACR accounts
 * @property location The location where the registry exists
 * @property storageAccountDetails List of storage accounts
 */
public data class RegistryRegionArmDetailsArgs(
    public val acrDetails: Output<List<AcrDetailsArgs>>? = null,
    public val location: Output<String>? = null,
    public val storageAccountDetails: Output<List<StorageAccountDetailsArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs.builder()
            .acrDetails(
                acrDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .storageAccountDetails(
                storageAccountDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [RegistryRegionArmDetailsArgs].
 */
@PulumiTagMarker
public class RegistryRegionArmDetailsArgsBuilder internal constructor() {
    private var acrDetails: Output<List<AcrDetailsArgs>>? = null

    private var location: Output<String>? = null

    private var storageAccountDetails: Output<List<StorageAccountDetailsArgs>>? = null

    /**
     * @param value List of ACR accounts
     */
    @JvmName("vfxnrbivvayxvrlk")
    public suspend fun acrDetails(`value`: Output<List<AcrDetailsArgs>>) {
        this.acrDetails = value
    }

    @JvmName("exwbxtnoyasoslnu")
    public suspend fun acrDetails(vararg values: Output<AcrDetailsArgs>) {
        this.acrDetails = Output.all(values.asList())
    }

    /**
     * @param values List of ACR accounts
     */
    @JvmName("cqktbtrotueuxpok")
    public suspend fun acrDetails(values: List<Output<AcrDetailsArgs>>) {
        this.acrDetails = Output.all(values)
    }

    /**
     * @param value The location where the registry exists
     */
    @JvmName("hbdxrsiqxgpgwmda")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value List of storage accounts
     */
    @JvmName("umsgxggchqovhfyx")
    public suspend fun storageAccountDetails(`value`: Output<List<StorageAccountDetailsArgs>>) {
        this.storageAccountDetails = value
    }

    @JvmName("tlguwjamdwbrhjvq")
    public suspend fun storageAccountDetails(vararg values: Output<StorageAccountDetailsArgs>) {
        this.storageAccountDetails = Output.all(values.asList())
    }

    /**
     * @param values List of storage accounts
     */
    @JvmName("vjlnymwsgtaqypsq")
    public suspend fun storageAccountDetails(values: List<Output<StorageAccountDetailsArgs>>) {
        this.storageAccountDetails = Output.all(values)
    }

    /**
     * @param value List of ACR accounts
     */
    @JvmName("yfpeixupjhvbwdlv")
    public suspend fun acrDetails(`value`: List<AcrDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acrDetails = mapped
    }

    /**
     * @param argument List of ACR accounts
     */
    @JvmName("mbhqovpqqdcyesfj")
    public suspend fun acrDetails(argument: List<suspend AcrDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { AcrDetailsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.acrDetails = mapped
    }

    /**
     * @param argument List of ACR accounts
     */
    @JvmName("rxfttwculylusqmn")
    public suspend fun acrDetails(vararg argument: suspend AcrDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { AcrDetailsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.acrDetails = mapped
    }

    /**
     * @param argument List of ACR accounts
     */
    @JvmName("msykvsjxbppuyach")
    public suspend fun acrDetails(argument: suspend AcrDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AcrDetailsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.acrDetails = mapped
    }

    /**
     * @param values List of ACR accounts
     */
    @JvmName("uaeunusoapxnfrxf")
    public suspend fun acrDetails(vararg values: AcrDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acrDetails = mapped
    }

    /**
     * @param value The location where the registry exists
     */
    @JvmName("yhownhoatrbjmeof")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value List of storage accounts
     */
    @JvmName("oyfmqnoqgbltotsd")
    public suspend fun storageAccountDetails(`value`: List<StorageAccountDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountDetails = mapped
    }

    /**
     * @param argument List of storage accounts
     */
    @JvmName("kywdittnwagfxstu")
    public suspend
    fun storageAccountDetails(argument: List<suspend StorageAccountDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StorageAccountDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageAccountDetails = mapped
    }

    /**
     * @param argument List of storage accounts
     */
    @JvmName("mgbrxkieqdqphpsn")
    public suspend fun storageAccountDetails(
        vararg
        argument: suspend StorageAccountDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StorageAccountDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageAccountDetails = mapped
    }

    /**
     * @param argument List of storage accounts
     */
    @JvmName("osenpqpqbocveskp")
    public suspend
    fun storageAccountDetails(argument: suspend StorageAccountDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(StorageAccountDetailsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.storageAccountDetails = mapped
    }

    /**
     * @param values List of storage accounts
     */
    @JvmName("axhwajlaxxdgbcwe")
    public suspend fun storageAccountDetails(vararg values: StorageAccountDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountDetails = mapped
    }

    internal fun build(): RegistryRegionArmDetailsArgs = RegistryRegionArmDetailsArgs(
        acrDetails = acrDetails,
        location = location,
        storageAccountDetails = storageAccountDetails,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/RegistryRegionArmDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Details for each region the registry is in
 * @property acrDetails List of ACR accounts
 * @property location The location where the registry exists
 * @property storageAccountDetails List of storage accounts
 */
public data class RegistryRegionArmDetailsArgs(
    public val acrDetails: Output<List<AcrDetailsArgs>>? = null,
    public val location: Output<String>? = null,
    public val storageAccountDetails: Output<List<StorageAccountDetailsArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.RegistryRegionArmDetailsArgs.builder()
            .acrDetails(
                acrDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .storageAccountDetails(
                storageAccountDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [RegistryRegionArmDetailsArgs].
 */
@PulumiTagMarker
public class RegistryRegionArmDetailsArgsBuilder internal constructor() {
    private var acrDetails: Output<List<AcrDetailsArgs>>? = null

    private var location: Output<String>? = null

    private var storageAccountDetails: Output<List<StorageAccountDetailsArgs>>? = null

    /**
     * @param value List of ACR accounts
     */
    @JvmName("hykifrodtwxjkqgh")
    public suspend fun acrDetails(`value`: Output<List<AcrDetailsArgs>>) {
        this.acrDetails = value
    }

    @JvmName("bnxkrtqydmaghcbw")
    public suspend fun acrDetails(vararg values: Output<AcrDetailsArgs>) {
        this.acrDetails = Output.all(values.asList())
    }

    /**
     * @param values List of ACR accounts
     */
    @JvmName("knmasybaapiylarn")
    public suspend fun acrDetails(values: List<Output<AcrDetailsArgs>>) {
        this.acrDetails = Output.all(values)
    }

    /**
     * @param value The location where the registry exists
     */
    @JvmName("mvxrllpgxbjcntkm")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value List of storage accounts
     */
    @JvmName("ooqlkhldtgkcsapn")
    public suspend fun storageAccountDetails(`value`: Output<List<StorageAccountDetailsArgs>>) {
        this.storageAccountDetails = value
    }

    @JvmName("cmeudksgpjmfhnyv")
    public suspend fun storageAccountDetails(vararg values: Output<StorageAccountDetailsArgs>) {
        this.storageAccountDetails = Output.all(values.asList())
    }

    /**
     * @param values List of storage accounts
     */
    @JvmName("gekdsmtxgkhcnhcr")
    public suspend fun storageAccountDetails(values: List<Output<StorageAccountDetailsArgs>>) {
        this.storageAccountDetails = Output.all(values)
    }

    /**
     * @param value List of ACR accounts
     */
    @JvmName("hdtqsqahinjplrjf")
    public suspend fun acrDetails(`value`: List<AcrDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acrDetails = mapped
    }

    /**
     * @param argument List of ACR accounts
     */
    @JvmName("qgwpartxeemafary")
    public suspend fun acrDetails(argument: List<suspend AcrDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { AcrDetailsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.acrDetails = mapped
    }

    /**
     * @param argument List of ACR accounts
     */
    @JvmName("yteuuvplhfqdnxbo")
    public suspend fun acrDetails(vararg argument: suspend AcrDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { AcrDetailsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.acrDetails = mapped
    }

    /**
     * @param argument List of ACR accounts
     */
    @JvmName("pfquknxiulljmaxx")
    public suspend fun acrDetails(argument: suspend AcrDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AcrDetailsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.acrDetails = mapped
    }

    /**
     * @param values List of ACR accounts
     */
    @JvmName("dexyuxhtsdomtjbs")
    public suspend fun acrDetails(vararg values: AcrDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acrDetails = mapped
    }

    /**
     * @param value The location where the registry exists
     */
    @JvmName("ikdwpqesdrkxmugj")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value List of storage accounts
     */
    @JvmName("eshabhxnkgfmqwbh")
    public suspend fun storageAccountDetails(`value`: List<StorageAccountDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountDetails = mapped
    }

    /**
     * @param argument List of storage accounts
     */
    @JvmName("mlfqogpserbklohi")
    public suspend
    fun storageAccountDetails(argument: List<suspend StorageAccountDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StorageAccountDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageAccountDetails = mapped
    }

    /**
     * @param argument List of storage accounts
     */
    @JvmName("xxydmvhwctsjyglb")
    public suspend fun storageAccountDetails(
        vararg
        argument: suspend StorageAccountDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StorageAccountDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageAccountDetails = mapped
    }

    /**
     * @param argument List of storage accounts
     */
    @JvmName("imfoqyleqebesyub")
    public suspend
    fun storageAccountDetails(argument: suspend StorageAccountDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(StorageAccountDetailsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.storageAccountDetails = mapped
    }

    /**
     * @param values List of storage accounts
     */
    @JvmName("nuakaipavloeqgop")
    public suspend fun storageAccountDetails(vararg values: StorageAccountDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountDetails = mapped
    }

    internal fun build(): RegistryRegionArmDetailsArgs = RegistryRegionArmDetailsArgs(
        acrDetails = acrDetails,
        location = location,
        storageAccountDetails = storageAccountDetails,
    )
}
